@@ -10,8 +10,28 @@
 #ifndef XTENSOR_ZARR_CONFIG_HPP
 #define XTENSOR_ZARR_CONFIG_HPP
 
+#ifdef _WIN32
+    #ifdef XTENSOR_ZARR_STATIC_LIB
+        #define XTENSOR_ZARR_API
+    #else
+        #ifdef XTENSOR_ZARR_EXPORTS
+            #define XTENSOR_ZARR_API __declspec(dllexport)
+        #else
+            #define XTENSOR_ZARR_API __declspec(dllimport)
+        #endif
+    #endif
+#else
+    #define XTENSOR_ZARR_API
+#endif
+
+// Project version
 #define XTENSOR_ZARR_VERSION_MAJOR 0
 #define XTENSOR_ZARR_VERSION_MINOR 0
-#define XTENSOR_ZARR_VERSION_PATCH 3
+#define XTENSOR_ZARR_VERSION_PATCH 5
+
+// Binary version
+#define XTENSOR_ZARR_BINARY_CURRENT 0
+#define XTENSOR_ZARR_BINARY_REVISION 0
+#define XTENSOR_ZARR_BINARY_AGE 0
 
 #endif
